@@ -38,7 +38,7 @@ Action::Action()
 Action::~Action() = default;
 Action &Action::operator=(const Action &other)
 {
-    d.reset(new ActionPrivate(*other.d));
+    d = std::make_unique<ActionPrivate>(*other.d);
     return *this;
 }
 
